from typing import List

from bluer_options.terminal import show_usage


def help_open(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@journal",
            "open",
            "[home | <YYYY-MM-DD>]",
        ],
        "open journal.",
        mono=mono,
    )



from tqdm import tqdm
from typing import Dict

from blueness import module

from bluer_journal import NAME
from bluer_journal.classes.page import JournalPage
from bluer_journal.classes.journal import journal
from bluer_journal.logger import logger


NAME = module.name(__file__, NAME)


def find_todo_items(
    verbose: bool = False,
) -> Dict[str, str]:
    list_of_pages = journal.list_of_pages(log=verbose)

    dict_of_todos: Dict[str, str] = {}
    for page_title in tqdm(list_of_pages):
        if page_title == "Home":
            continue

        page = JournalPage(
            title=page_title,
            load=True,
            verbose=verbose,
        )

        for todo_item in page.list_of_todos():
            dict_of_todos[todo_item] = page_title

    dict_of_todos = dict(sorted(dict_of_todos.items()))

    logger.info(f"{len(dict_of_todos)} todo(s).")
    for index, (todo_item, page_title) in enumerate(dict_of_todos.items()):
        logger.info(f"#{index+1: 3d} - {todo_item} ({page_title})")

    return dict_of_todos


def sync_checklist(
    verbose: bool = False,
) -> bool:
    logger.info(f"{NAME}.sync_checklist ...")

    Home = JournalPage(
        title="Home",
        load=True,
        verbose=verbose,
    )

    dict_of_todos = find_todo_items(verbose=True)

    Home.sections["todo (auto)"] = [
        "- [ ] [[{}]]: {}".format(page_title, todo_item)
        for todo_item, page_title in dict_of_todos.items()
    ]

    return Home.save()



from typing import List
import os
import glob

from bluer_objects.env import abcli_path_git
from bluer_objects import file

from bluer_journal.env import BLUER_JOURNAL_REPO
from bluer_journal.logger import logger


class Journal:
    def __init__(self): ...

    def list_of_pages(
        self,
        log: bool = False,
    ) -> List[str]:
        list_of_pages = sorted(
            [
                file.name(filename)
                for filename in glob.glob(
                    os.path.join(
                        self.path,
                        "*.md",
                    )
                )
            ]
        )

        if log:
            logger.info(
                "{} page(s): {}".format(
                    len(list_of_pages),
                    ", ".join(
                        list_of_pages[:3] + ["..."],
                    ),
                )
            )

        return list_of_pages

    @property
    def path(self):
        return os.path.join(
            abcli_path_git,
            f"{BLUER_JOURNAL_REPO}.wiki",
        )


journal = Journal()



import git
import pytest

from bluer_objects import path

from bluer_journal.env import BLUER_JOURNAL_REPO
from bluer_journal.classes.journal import journal


@pytest.fixture
def journal_checkout():
    if not path.exists(journal.path):
        git.Repo.clone_from(
            f"https://github.com/kamangir/{BLUER_JOURNAL_REPO}.wiki.git",
            journal.path,
        )



from bluer_journal.classes.page import JournalPage
from bluer_journal.tests.fixtures import journal_checkout


def test_journal_page(journal_checkout):
    page = JournalPage(
        title="Home",
        load=True,
    )

    page.generate()

    assert page.save()

    list_of_todos = page.list_of_todos()
    assert isinstance(list_of_todos, list)
